==> azure_svc_synapse-0.2.0.crate: azure_svc_synapse-0.2.0/README.md <==
# azure_svc_synapse crate

This is a generated [Azure SDK for Rust](https://github.com/Azure/azure-sdk-for-rust) crate from the Azure REST API specifications listed in:

https://github.com/Azure/azure-rest-api-specs/blob/main/specification/synapse/data-plane/readme.md

To get started with these generated service crates, see the [examples](https://github.com/Azure/azure-sdk-for-rust/blob/main/services/README.md#examples).

The default tag is `package-artifacts-composite-v3`.

The following [tags](https://github.com/Azure/azure-sdk-for-rust/blob/main/services/tags.md) are available:

- `package-artifacts-composite-v3` has 84 operations from 5 API versions: `2019-06-01-preview`, `2020-12-01`, `2021-06-01-preview`, `2021-07-01-preview`, `2021-11-01-preview`. Use crate feature `package-artifacts-composite-v3` to enable. The operations will be in the `package_artifacts_composite_v3` module.
- `package-artifacts-composite-v2` has 80 operations from 4 API versions: `2019-06-01-preview`, `2020-12-01`, `2021-06-01-preview`, `2021-11-01-preview`. Use crate feature `package-artifacts-composite-v2` to enable. The operations will be in the `package_artifacts_composite_v2` module.
- `package-artifacts-composite-v1` has 80 operations from 3 API versions: `2019-06-01-preview`, `2020-12-01`, `2021-06-01-preview`. Use crate feature `package-artifacts-composite-v1` to enable. The operations will be in the `package_artifacts_composite_v1` module.
- `package-artifacts-2021-06-01-preview` has 77 operations from 3 API versions: `2019-06-01-preview`, `2019-11-01-preview`, `2021-06-01-preview`. Use crate feature `package-artifacts-2021-06-01-preview` to enable. The operations will be in the `package_artifacts_2021_06_01_preview` module.
- `package-vnet-2021-06-01-preview` has 4 operations from 1 API versions: `2021-06-01-preview`. Use crate feature `package-vnet-2021-06-01-preview` to enable. The operations will be in the `package_vnet_2021_06_01_preview` module.
- `package-kql-script-2021-06-preview` has 5 operations from 2 API versions: `2019-06-01-preview`, `2021-06-01-preview`. Use crate feature `package-kql-script-2021-06-preview` to enable. The operations will be in the `package_kql_script_2021_06_preview` module.
- `package-link-connection-2021-12-01-preview` has 11 operations from 1 API versions: `2021-12-01-preview`. Use crate feature `package-link-connection-2021-12-01-preview` to enable. The operations will be in the `package_link_connection_2021_12_01_preview` module.
- `package-artifacts-2020-12-01` has 72 operations from 2 API versions: `2019-06-01-preview`, `2020-12-01`. Use crate feature `package-artifacts-2020-12-01` to enable. The operations will be in the `package_artifacts_2020_12_01` module.
- `package-monitoring-2020-12-01` has 2 operations from 1 API versions: `2020-12-01`. Use crate feature `package-monitoring-2020-12-01` to enable. The operations will be in the `package_monitoring_2020_12_01` module.
- `package-access-control-2020-12-01` has 8 operations from 1 API versions: `2020-12-01`. Use crate feature `package-access-control-2020-12-01` to enable. The operations will be in the `package_access_control_2020_12_01` module.
- `package-vnet-2020-12-01` has 4 operations from 1 API versions: `2020-12-01`. Use crate feature `package-vnet-2020-12-01` to enable. The operations will be in the `package_vnet_2020_12_01` module.
- `package-spark-2020-12-01` has 13 operations from 1 API versions: `2020-12-01`. Use crate feature `package-spark-2020-12-01` to enable. The operations will be in the `package_spark_2020_12_01` module.
- `package-spark-2019-11-01-preview` has 13 operations from 1 API versions: `2019-11-01-preview`. Use crate feature `package-spark-2019-11-01-preview` to enable. The operations will be in the `package_spark_2019_11_01_preview` module.
- `package-artifacts-2019-06-01-preview` has 69 operations from 2 API versions: `2019-06-01-preview`, `2019-11-01-preview`. Use crate feature `package-artifacts-2019-06-01-preview` to enable. The operations will be in the `package_artifacts_2019_06_01_preview` module.
- `package-access-control-2020-02-01-preview` has 7 operations from 1 API versions: `2020-02-01-preview`. Use crate feature `package-access-control-2020-02-01-preview` to enable. The operations will be in the `package_access_control_2020_02_01_preview` module.
- `package-access-control-2020-08-01-preview` has 8 operations from 1 API versions: `2020-08-01-preview`. Use crate feature `package-access-control-2020-08-01-preview` to enable. The operations will be in the `package_access_control_2020_08_01_preview` module.
- `package-vnet-2019-06-01-preview` has 4 operations from 1 API versions: `2019-06-01-preview`. Use crate feature `package-vnet-2019-06-01-preview` to enable. The operations will be in the `package_vnet_2019_06_01_preview` module.
- `package-monitoring-2019-11-01-preview` has 2 operations from 1 API versions: `2019-11-01-preview`. Use crate feature `package-monitoring-2019-11-01-preview` to enable. The operations will be in the `package_monitoring_2019_11_01_preview` module.

==> azure_svc_synapse-0.3.0.crate: azure_svc_synapse-0.3.0/README.md <==
# azure_svc_synapse crate

This is a generated [Azure SDK for Rust](https://github.com/Azure/azure-sdk-for-rust) crate from the Azure REST API specifications listed in:

https://github.com/Azure/azure-rest-api-specs/blob/main/specification/synapse/data-plane/readme.md

To get started with these generated service crates, see the [examples](https://github.com/Azure/azure-sdk-for-rust/blob/main/services/README.md#examples).

The default tag is `package-artifacts-composite-v4`.

The following [tags](https://github.com/Azure/azure-sdk-for-rust/blob/main/services/tags.md) are available:

- `package-artifacts-composite-v4` has 101 operations from 6 API versions: `2019-06-01-preview`, `2020-12-01`, `2021-06-01-preview`, `2021-07-01-preview`, `2021-11-01-preview`, `2021-12-01-preview`. Use crate feature `package-artifacts-composite-v4` to enable. The operations will be in the `package_artifacts_composite_v4` module.
- `package-artifacts-composite-v3` has 90 operations from 5 API versions: `2019-06-01-preview`, `2020-12-01`, `2021-06-01-preview`, `2021-07-01-preview`, `2021-11-01-preview`. Use crate feature `package-artifacts-composite-v3` to enable. The operations will be in the `package_artifacts_composite_v3` module.
- `package-artifacts-composite-v2` has 86 operations from 4 API versions: `2019-06-01-preview`, `2020-12-01`, `2021-06-01-preview`, `2021-11-01-preview`. Use crate feature `package-artifacts-composite-v2` to enable. The operations will be in the `package_artifacts_composite_v2` module.
- `package-artifacts-composite-v1` has 86 operations from 3 API versions: `2019-06-01-preview`, `2020-12-01`, `2021-06-01-preview`. Use crate feature `package-artifacts-composite-v1` to enable. The operations will be in the `package_artifacts_composite_v1` module.
- `package-artifacts-2021-06-01-preview` has 83 operations from 3 API versions: `2019-06-01-preview`, `2019-11-01-preview`, `2021-06-01-preview`. Use crate feature `package-artifacts-2021-06-01-preview` to enable. The operations will be in the `package_artifacts_2021_06_01_preview` module.
- `package-vnet-2021-06-01-preview` has 4 operations from 1 API versions: `2021-06-01-preview`. Use crate feature `package-vnet-2021-06-01-preview` to enable. The operations will be in the `package_vnet_2021_06_01_preview` module.
- `package-kql-script-2021-06-preview` has 5 operations from 2 API versions: `2019-06-01-preview`, `2021-06-01-preview`. Use crate feature `package-kql-script-2021-06-preview` to enable. The operations will be in the `package_kql_script_2021_06_preview` module.
- `package-link-connection-2021-12-01-preview` has 11 operations from 1 API versions: `2021-12-01-preview`. Use crate feature `package-link-connection-2021-12-01-preview` to enable. The operations will be in the `package_link_connection_2021_12_01_preview` module.
- `package-artifacts-2020-12-01` has 78 operations from 2 API versions: `2019-06-01-preview`, `2020-12-01`. Use crate feature `package-artifacts-2020-12-01` to enable. The operations will be in the `package_artifacts_2020_12_01` module.
- `package-monitoring-2020-12-01` has 2 operations from 1 API versions: `2020-12-01`. Use crate feature `package-monitoring-2020-12-01` to enable. The operations will be in the `package_monitoring_2020_12_01` module.
- `package-access-control-2020-12-01` has 8 operations from 1 API versions: `2020-12-01`. Use crate feature `package-access-control-2020-12-01` to enable. The operations will be in the `package_access_control_2020_12_01` module.
- `package-vnet-2020-12-01` has 4 operations from 1 API versions: `2020-12-01`. Use crate feature `package-vnet-2020-12-01` to enable. The operations will be in the `package_vnet_2020_12_01` module.
- `package-spark-2020-12-01` has 13 operations from 1 API versions: `2020-12-01`. Use crate feature `package-spark-2020-12-01` to enable. The operations will be in the `package_spark_2020_12_01` module.
- `package-spark-2019-11-01-preview` has 13 operations from 1 API versions: `2019-11-01-preview`. Use crate feature `package-spark-2019-11-01-preview` to enable. The operations will be in the `package_spark_2019_11_01_preview` module.
- `package-artifacts-2019-06-01-preview` has 75 operations from 2 API versions: `2019-06-01-preview`, `2019-11-01-preview`. Use crate feature `package-artifacts-2019-06-01-preview` to enable. The operations will be in the `package_artifacts_2019_06_01_preview` module.
- `package-access-control-2020-02-01-preview` has 7 operations from 1 API versions: `2020-02-01-preview`. Use crate feature `package-access-control-2020-02-01-preview` to enable. The operations will be in the `package_access_control_2020_02_01_preview` module.
- `package-access-control-2020-08-01-preview` has 8 operations from 1 API versions: `2020-08-01-preview`. Use crate feature `package-access-control-2020-08-01-preview` to enable. The operations will be in the `package_access_control_2020_08_01_preview` module.
- `package-vnet-2019-06-01-preview` has 4 operations from 1 API versions: `2019-06-01-preview`. Use crate feature `package-vnet-2019-06-01-preview` to enable. The operations will be in the `package_vnet_2019_06_01_preview` module.
- `package-monitoring-2019-11-01-preview` has 2 operations from 1 API versions: `2019-11-01-preview`. Use crate feature `package-monitoring-2019-11-01-preview` to enable. The operations will be in the `package_monitoring_2019_11_01_preview` module.
